function add_folders()

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This script is used to add the required folders to the search path of
% MATLAB. If the folder names are changed, then they should also be changed
% here. Alternatively, each folder can be added to the search path
% manually.
%
% Additionally, the required MATLAB toolboxes for the corresponding scripts
% can be checked. The information about the necessary MATLAB packages is
% stored in the 'req_MATLAB_packages' struct. Use this option if you 
% receive an error message due to missing toolboxes. Otherwise, this
% routine is not mandatory.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

current_path = pwd;

% adjust if folder name is changed
str_data      = '\data folder';
str_light     = '\light profile';
str_opt_props = '\optical cell properties';
str_param_est = '\parameter estimation';
str_plot      = '\plotter';
str_optional  = '\optional';

% The data folder should include all the data used for computations.
addpath([current_path,str_data]);

% This folder contains the 1D-RTE script to calculate the light profile 
% inside the apparatus (e.g.: flat-panel photobioreactor).
addpath([current_path,str_light]);

% This folder contains the Lorenz-Mie script for the computation of optical
% properties of the microalgal cells.
addpath([current_path,str_opt_props]);

% This folder contains the scripts for parameter estimation.
addpath([current_path,str_param_est]);

% This folder contains the script that can be used to plot the simulated
% data and to calculate the statistical parameters (including: R², RMSE,
% normalized RMSE, MBE, normalized MBE and AICc).
addpath([current_path,str_plot]);

% This folder contains the optional scripts that can be used as caller
% functions to compute the light profiles and to fit the logistic function
% to the pigment data. Both should be done before parameter estimation if
% new/own data is used in this case!
addpath([current_path,str_optional]);

quest = 'Check for required MATLAB packages?';
p_check = questdlg(quest,'Package check','Yes','No','No');

if strcmp(p_check,'Yes')
    files_light     = dir([current_path,str_light]);
    files_opt_props = dir([current_path,str_opt_props]);
    files_param_est = dir([current_path,str_param_est]);
    files_plot      = dir([current_path,str_plot]);
    files_optional  = dir([current_path,str_optional]);
    
    names_light     = {files_light.name};
    names_light     = names_light(~strncmp(names_light,'.',1));
    names_opt_props = {files_opt_props.name};
    names_opt_props = names_opt_props(~strncmp(names_opt_props,'.',1));
    names_param_est = {files_param_est.name};
    names_param_est = names_param_est(~strncmp(names_param_est,'.',1));
    names_plot      = {files_plot.name};
    names_plot      = names_plot(~strncmp(names_plot,'.',1));
    names_optional  = {files_optional.name};
    names_optional  = names_optional(~strncmp(names_optional,'.',1));
    
    names_all       = {names_light{1:end},names_opt_props{1:end},...
        names_param_est{1:end},names_plot{1:end},names_optional{1:end}};

    [idx,slct_logic]=listdlg('PromptString',...
        {'Select a script to check for the required MATLAB toolboxes.',...
        'Multiple scripts can be selected at once!'},...
        'SelectionMode','multiple','ListString',names_all,...
        'ListSize',[300,200]);

    if slct_logic == true
        for idx1 = 1:length(idx)
            name_script = erase((names_all{idx(idx1)}),'.m');
            [~,req_MATLAB_packages.(name_script)] = ...
                matlab.codetools.requiredFilesAndProducts(name_script);
        end

        assignin('base','req_MATLAB_packages',req_MATLAB_packages);
        disp('Required MATLAB toolboxes are listed in: req_MATLAB_packages!');
    else
        disp('Selection canceled!');
    end
else
    return
end