function [PAR_PFD_dzR,spctrm_PFD_dzR] = calculate_light_grad(PFD0,LED_spctrm,c_bdm,spctrm_sigma_bdm,spctrm_kappa_bdm,b634)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This script computes the light gradient inside the flat panel
% photobioreactor (PBR) or the photosynthesis measurement cell (PMC) with
% a double-sided illumination.
%
% The 1D-RTE from:
%
% Cornet, J.-F.; Dussap, C. G.; Gros, J.-B.; Binois, C.; Lasseur, C. 
% (1995): A simplified monodimensional approach for modeling coupling 
% between radiant light transfer and growth kinetics in photobioreactors. 
% In: Chemical Engineering Science 50 (9), 
% S. 1489–1500. DOI: 10.1016/0009-2509(95)00022-W.
%
% and
%
% Kandilian, R.; Pruvost, J.; Artu, A.; Lemasson, C.; Legrand, J.;
% Pilon, L. (2016): Comparison of experimentally and theoretically
% determined radiation characteristics of photosynthetic microorganisms.
% In: Journal of Quantitative Spectroscopy and Radiative Transfer 175,
% S. 30–45. DOI: 10.1016/j.jqsrt.2016.01.031.
%
% was modified for the case of a double-sided illumination of a PBR/PMC.
%
% Inputs:
% PFD0: actinic PFD at the PBR/PMC surface [µmol/(m²*s)]
% LED_spctrm: light spectrum of the utilized LED-arrays [µmol/(m²*s)]
% c_bdm: dry biomass concentration [kg/m³]
% spctrm_sigma_bdm: biomass-specific, spectral absorption cross-section
% [m²/kg]
% spctrm_kappa_bdm: biomass-specific, spectral scattering cross-section
% [m²/kg]
% b634: backscattering fraction at a light wavelength of 634 nm [-]
%
% Output:
% PAR_PFD_dzR: actinic PFD along the PBR/PMC depth [µmol/(m²*s)]
% spctrm_PFD_dzR: spectral actinic PFD along the PBR/PMC depth [µmol/(m²*s)]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

spctrm  = 400:700;
dzR     = linspace(0,0.02,20); % should be changed if PBR depth does not equal 20 mm!
n2      = 1.473;    % refractive index of borosilicate glas [-]
n1      = 1.000292; % refractive index of air [-]

dspctrm     = PFD0./trapz(LED_spctrm);
spctrm_PFD0 = LED_spctrm'.*dspctrm;

% fraction of the reflected light on the PBR/PMC surface (Fresnel's equation;
% simplified formulation for the case of perpendicular incidence of light 
% on the surface)
ref     = abs((n1-n2)/(n1+n2))^2;
    
alpha = sqrt(spctrm_sigma_bdm./(spctrm_sigma_bdm+2.*b634.*spctrm_kappa_bdm));
delta = c_bdm.*sqrt(spctrm_sigma_bdm...
    .*(spctrm_sigma_bdm+2.*b634.*spctrm_kappa_bdm));

% preallocation
spctrm_PFD_dzR = zeros(length(dzR),length(spctrm));
PAR_PFD_dzR   = zeros(1,length(dzR));

for idx = 1:length(dzR)
    for idx1 = 1:length(spctrm)
        % 1D-RTE for a flat-panel PBR/PMC illuminated from both sides
        spctrm_PFD_dzR(idx,idx1) = (1-ref)...
            *spctrm_PFD0(idx1)*2*((1+alpha(idx1))...
            *(exp(delta(idx1)*(max(dzR)-dzR(idx)))...
            +exp(delta(idx1)*dzR(idx)))-(1-alpha(idx1))...
            *(exp(-delta(idx1)*(max(dzR)-dzR(idx)))...
            +exp(-delta(idx1)*dzR(idx))))...
            /((1+alpha(idx1))^2*exp(delta(idx1)*max(dzR))...
            -(1-alpha(idx1))^2*exp(-delta(idx1)*max(dzR)));
    end

    PAR_PFD_dzR(idx) = trapz(spctrm_PFD_dzR(idx,:),2);
end