function [avrg_sigma_chl,spctrm_sigma_chl,spctrm_sigma_bdm,spctrm_kappa_bdm,b634] = calculate_opt_props(m_ccell,w_chla,w_chlb,w_car,Ea_chla,Ea_chlb,Ea_car,M_chla,M_chlb)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This script calculates the optical properties of microalgal cells
% according to the Lorenz-Mie theory.
%
% Inputs:
% m_ccell: refractive index (RI) of the cell "core" [-]
% w_chla, w_chlb, w_car: weight fractions of chla, chlb & car [kg/kg]
% Ea_chla: in vivo absorption spectra of chla [m²/kg]
% Ea_chlb: in vivo absorption spectra of chlb [m²/kg]
% Ea_car: in vivo absorption spectra of photoprotective car [m²/kg]
% M_chla, M_chlb: molecular weights of chla & chlb [g/mol]
%
% Ea_i data is available here (requires interpolation between 400-700 nm
% with 1 nm steps):
%
% Bidigare, R. R.; Ondrusek, M. E.; Morrow, J. H.; Kiefer, D. A. (1990): 
% In-vivo absorption properties of algal pigments. 
% In: Richard W. Spinrad (Hg.): Ocean Optics X. Orlando '90, 16-20 April. 
% Orlando, FL, United States: SPIE (SPIE Proceedings), S. 290.
%
% or in (only 400-700 nm range is required):
%
% Dauchet, J.; Blanco, S.; Cornet, J.-F.; Fournier, R. (2015): 
% Calculation of the radiative properties of photosynthetic microorganisms. 
% In: Journal of Quantitative Spectroscopy and Radiative Transfer 161, 
% S. 60–84. DOI: 10.1016/j.jqsrt.2015.03.025.
% -> http://edstar.lmd.jussieu.fr/databases
%
% m_ccel was calculated as described in:
%
% Kandilian, R.; Pruvost, J.; Artu, A.; Lemasson, C.; Legrand, J.; 
% Pilon, L. (2016): Comparison of experimentally and theoretically 
% determined radiation characteristics of photosynthetic microorganisms. 
% In: Journal of Quantitative Spectroscopy and Radiative Transfer 175, 
% S. 30–45. DOI: 10.1016/j.jqsrt.2016.01.031.
%
% The imaginary part of the RI of the cell "core" (k_ccell) was determined
% according to Kandilian et al. (2016). k_ccell was then used to calculate
% the corresponding real part of the RI (n_ccell) using the 
% singly-substractive Kronig-Kramers (ssKK) relation.
% The ssKK script utilized can be found in:
%
% Lucarini, V.; Peiponen, K.-E.; Saarinen, J. J.; Vartiainen, E. M. (2005):
% Kramers-Kronig relations in optical materials research. Berlin, 
% Heidelberg: Springer-Verlag Berlin Heidelberg 
% (Springer Series in Optical Sciences, 110).
%
% with: m_ccell = n_ccell + i*k_ccell
%
% Outputs:
% avrg_sigma_chl: PAR-averaged absorption cross-section of chl [m²]
% spctrm_sigma_chl: spectral absorption cross-section of chl [m²]
% spctrm_sigma_bdm: biomass-specific, spectral absorption cross-section
% [m²/kg]
% spctrm_kappa_bdm: biomass-specific, spectral scattering cross-section
% [m²/kg]
% b634: backscattering fraction at a light wavelength of 634 nm
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

r_wcell         = 2.72;             % cell radius [µm]

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% value derived from:
%
% Gerken, H. G.; Donohoe, B.; Knoshaug, E. P. (2013): Enzymatic cell wall 
% degradation of Chlorella vulgaris and other microalgae for biofuels 
% production. In: Planta 237 (1), 
% S. 239–253. DOI: 10.1007/s00425-012-1765-0.

d_wall          = 0.078;            % diameter of the cell wall [µm]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

r_ccell         = r_wcell-d_wall;   % cell "core" radius [µm]

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% values taken from:
%
% 1: Dauchet, J.; Blanco, S.; Cornet, J.-F.; Fournier, R. (2015): 
% Calculation of the radiative properties of photosynthetic microorganisms. 
% In: Journal of Quantitative Spectroscopy and Radiative Transfer 161, 
% S. 60–84. DOI: 10.1016/j.jqsrt.2015.03.025.
%
% 2: Kandilian, R.; Pruvost, J.; Artu, A.; Lemasson, C.; Legrand, J.; 
% Pilon, L. (2016): Comparison of experimentally and theoretically 
% determined radiation characteristics of photosynthetic microorganisms. 
% In: Journal of Quantitative Spectroscopy and Radiative Transfer 175, 
% S. 30–45. DOI: 10.1016/j.jqsrt.2016.01.031.
%
% and
%
% 3: Aas, E. (1996): Refractive index of phytoplankton derived from its 
% metabolite composition. In: J Plankton Res 18 (12), 
% S. 2223–2249. DOI: 10.1093/plankt/18.12.2223.

rho_bdm         = 1400;        % density of dry biomass [kg/m³] 1,2
x_water         = 0.78;        % fraction of water in biomass [-] 1,2
m_wcell         = 1.13*1.3325; % refractive index of the cell wall [-] 3
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

spctrm      = (400:700)';
theta       = (0:deg2rad(0.5):pi)';
ct          = cos(theta);
bsc         = theta >= pi/2;

% size parameters of the cell "core" (x_ccell) and the whole cell (y_wcell)
x_ccell     = 2*pi.*(r_ccell*1e-6)./(spctrm.*1e-9);
y_wcell     = 2*pi.*(r_wcell*1e-6)./(spctrm.*1e-9);

% preallocation
Qext_tot    = zeros(length(spctrm),1);
Qsca_tot    = zeros(length(spctrm),1);
Qabs_tot    = zeros(length(spctrm),1);
SPF         = zeros(length(theta),1);

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Determination of the optical cell properties according to the Lorenz-Mie
% theory. The script for coated spheres was adapted from:
% 
% Mätzler, C. (2002): MATLAB functions for Mie scattering and absorption.
% Version 2. Research Report No. 2002-11.
% Universität Bern, Institut für Angewandte Physik, Mikrowellenabteilung.
% Bern, Schweiz.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

for idx = 1:length(spctrm)
    nmax        = round(2+y_wcell(idx)+4*y_wcell(idx)^(1/3));
    n1          = nmax-1;
    n           = 1:nmax;
    cn          = 2*n+1;
    y2          = y_wcell(idx)^2;
    m           = (m_wcell/1.3325)/(m_ccell(idx)/1.3325);
    u           = m_ccell(idx)/1.3325*x_ccell(idx);
    v           = m_wcell/1.3325*x_ccell(idx);
    w           = m_wcell/1.3325*y_wcell(idx);
    mx          = max(abs(m_ccell(idx)/1.3325*y_wcell(idx)),...
        abs(m_wcell/1.3325*y_wcell(idx)));
    nmx         = round(max(nmax,mx)+16);
    dnx(nmx)    = 0+0*1i;

    for idx1 = nmx:-1:2
        dnx(idx1-1) = idx1./u-1/(dnx(idx1)+idx1./u);
    end

    dnu = dnx(n);

    for idx2 = nmx:-1:2
        dnx(idx2-1) = idx2./v-1/(dnx(idx2)+idx2./v);
    end

    dnv = dnx(n);

    for idx3 = nmx:-1:2
        dnx(idx3-1) = idx3./w-1/(dnx(idx3)+idx3./w);
    end

    dnw = dnx(n);

    nu      = (n+0.5);
    sv      = sqrt(0.5*pi*v);
    pv      = sv.*besselj(nu,v);
    sw      = sqrt(0.5*pi*w);
    pw      = sw.*besselj(nu,w);
    sy      = sqrt(0.5*pi*y_wcell(idx));
    py      = sy.*besselj(nu,y_wcell(idx));
    p1y     = [sin(y_wcell(idx)),py(1:n1)];
    chv     = -sv.*bessely(nu,v);
    chw     = -sw.*bessely(nu,w);
    chy     = -sy.*bessely(nu,y_wcell(idx));
    ch1y    = [cos(y_wcell(idx)),chy(1:n1)];
    gsy     = py-1i*chy;
    gs1y    = p1y-1i*ch1y;

    uu      = m.*dnu-dnv;
    vv      = dnu./m-dnv;
    fv      = pv./chv;
    ku1     = uu.*fv./pw;
    kv1     = vv.*fv./pw;
    ku2     = uu.*(pw-chw.*fv)+(pw./pv)./chv;
    kv2     = vv.*(pw-chw.*fv)+(pw./pv)./chv;
    dns1    = ku1./ku2;
    gns1    = kv1./kv2;

    dns     = dns1+dnw;
    gns     = gns1+dnw;
    a1      = dns./(m_wcell/1.3325)+n/y_wcell(idx);
    b1      = (m_wcell/1.3325).*gns+n/y_wcell(idx);

    an      = (py.*a1-p1y)./(gsy.*a1-gs1y);
    bn      = (py.*b1-p1y)./(gsy.*b1-gs1y);

    if spctrm(idx) == 634
        an634 = an;
        bn634 = bn;
    end

    anp     = real(an);
    anpp    = imag(an);
    bnp     = real(bn);
    bnpp    = imag(bn);

    clear g1
    g1(1:4,nmax)    = [0; 0; 0; 0];
    g1(1,1:n1)      = anp(2:nmax);
    g1(2,1:n1)      = anpp(2:nmax);
    g1(3,1:n1)      = bnp(2:nmax);
    g1(4,1:n1)      = bnpp(2:nmax);

    dn              = cn.*(anp+bnp);
    Qext_tot(idx)   = 2*sum(dn)/y2;
    en              = cn.*(anp.^2+anpp.^2+bnp.^2+bnpp.^2);
    Qsca_tot(idx)   = 2*sum(en)/y2;
    Qabs_tot(idx)   = Qext_tot(idx)-Qsca_tot(idx);
end

nmax634 = round(2+y_wcell(spctrm==634)+4*y_wcell(spctrm==634)^(1/3));
n634    = 1:nmax634;
n634_2  = (2*n634+1)./(n634.*(n634+1));

for idx = 1:length(theta)
    p(1) = 1;
    p(2) = 3*ct(idx);
    t(1) = ct(idx);
    t(2) = 3*cos(2*acos(ct(idx)));
    
    for idx1 = 3:nmax634
        p(idx1) = (2*idx1-1)./(idx1-1).*p(idx1-1).*ct(idx)-idx1...
            ./(idx1-1).*p(idx1-2);
        t(idx1) = idx1*ct(idx).*p(idx1)-(idx1+1).*p(idx1-1);
    end
    
    p   = n634_2.*p;
    t   = n634_2.*t;
    S1  = (an634*p'+bn634*t');
    S2  = (an634*t'+bn634*p');
    
    SPF(idx) = 0.634^2*(abs(S2)^2+abs(S1)^2)...
        /(2*pi^2*r_wcell^2*Qsca_tot(spctrm==634));
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

wf_chla     = w_chla/(w_chla+w_chlb+w_car);
wf_chlb     = w_chlb/(w_chla+w_chlb+w_car);
wf_car      = w_car/(w_chla+w_chlb+w_car);
Qabs_chl    = Qabs_tot.*(Ea_chla.*wf_chla+Ea_chlb.*wf_chlb)...
    ./(Ea_chla.*wf_chla+Ea_chlb.*wf_chlb+Ea_car.*wf_car);

% spectral absorption cross-section of Chlorophyll [m²/chl]
spctrm_sigma_chl = (3.*Qabs_chl./(4*r_wcell*1e-6*rho_bdm*(1-x_water))...
                   ./(w_chla+w_chlb).*((M_chla*1e-3)*w_chla...
                   /(w_chla+w_chlb)+(M_chlb*1e-3)*w_chlb...
                   /(w_chla+w_chlb))./6.02214076e23)';

% absorption cross-section of Chlorophyll averaged over PAR [m²/chl]
avrg_sigma_chl   = trapz(spctrm,spctrm_sigma_chl)./length(spctrm);

% spectral absorption cross-section of dry biomass [m²/kg]
spctrm_sigma_bdm = 3.*Qabs_tot./(4*r_wcell*1e-6*rho_bdm*(1-x_water));

% spectral scattering cross-section of dry biomass [m²/kg]
spctrm_kappa_bdm = 3.*Qsca_tot./(4*r_wcell*1e-6*rho_bdm*(1-x_water));

% backscattering fraction at 634 nm light wavelength [-]
b634             = 0.5*trapz(theta(bsc),SPF(bsc).*sin(theta(bsc)));
end