function [spctrm_sigma_bdm,spctrm_kappa_bdm,b634,mean_PAR_PFD,PAR_PFD_dzR,spctrm_PFD_dzR] = call_opt_props_light_grad(c_bdm,w_chla,w_chlb,w_car,m_ccell,PFD0)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function computes the optical properties of the microalgal cells 
% and the corresponding light profile inside a flat-panel photobioreactor
% or a measuring cell (illuminated from both sides in each case).
%
% Inputs:
% c_bdm: bio dry mass concentration [kg/m³ or g/L]
% w_chla, w_chlb, w_car: weight fractions of chla, chlb & car [kg/kg or g/g]
% m_ccell: refractive index (RI) of the cell core [-]
% PFD0: photon flux density (PFD) at the apparatus surface [µmol/m²/s]
%
% m_ccel was calculated as described in:
%
% Kandilian, R.; Pruvost, J.; Artu, A.; Lemasson, C.; Legrand, J.; 
% Pilon, L. (2016): Comparison of experimentally and theoretically 
% determined radiation characteristics of photosynthetic microorganisms. 
% In: Journal of Quantitative Spectroscopy and Radiative Transfer 175, 
% S. 30–45. DOI: 10.1016/j.jqsrt.2016.01.031.
%
% The imaginary part of the RI of the cell core (k_ccell) was determined
% according to Kandilian et al. (2016). k_ccell was then used to calculate
% the corresponding real part of the RI (n_ccell) using the 
% singly-substractive Kronig-Kramers (ssKK) relation.
% The ssKK script utilized can be found in:
%
% Lucarini, V.; Peiponen, K.-E.; Saarinen, J. J.; Vartiainen, E. M. (2005):
% Kramers-Kronig relations in optical materials research. Berlin, 
% Heidelberg: Springer-Verlag Berlin Heidelberg 
% (Springer Series in Optical Sciences, 110).
%
% with: m_ccell = n_ccell + i*k_ccell
%
% Outputs:
% spctrm_sigma_bdm: biomass-specific, spectral absorption cross-section
% [m²/kg]
% spctrm_kappa_bdm: biomass-specific, spectral scattering cross-section
% [m²/kg]
% b634: backscattering fraction at a light wavelength of 634 nm
% mean_PAR_PFD: PAR-averaged PFD (also averaged over the reactor depth 
% -> 20 mm in this case; should be changed if PBR depth does not equal 
% 20 mm!) [µmol/m²/s]
% PAR_PFD_dzR: integrated actinic PFD along the PBR depth [µmol/(m²*s)]
% spctrm_PFD_dzR: spectral actinic PFD along the PBR depth [µmol/(m²*s)]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

data = load('accl_fast_data.mat');

spctrm  = data.spctrm;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Ea_i data is available here (requires interpolation between 400-700 nm
% with 1 nm steps):
%
% Bidigare, R. R.; Ondrusek, M. E.; Morrow, J. H.; Kiefer, D. A. (1990): 
% In-vivo absorption properties of algal pigments. 
% In: Richard W. Spinrad (Hg.): Ocean Optics X. Orlando '90, 16-20 April. 
% Orlando, FL, United States: SPIE (SPIE Proceedings), S. 290.
%
% or in (only 400-700 nm range is required):
%
% Dauchet, J.; Blanco, S.; Cornet, J.-F.; Fournier, R. (2015): 
% Calculation of the radiative properties of photosynthetic microorganisms. 
% In: Journal of Quantitative Spectroscopy and Radiative Transfer 161, 
% S. 60–84. DOI: 10.1016/j.jqsrt.2015.03.025.
% -> http://edstar.lmd.jussieu.fr/databases

Ea_chla = data.Ea_chla;
Ea_chlb = data.Ea_chlb;
Ea_car  = data.Ea_car;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

M_chla  = data.M_chla;
M_chlb  = data.M_chlb;

dzR = linspace(0,0.02,20); % steps along the PBR depth; should be adjusted if PBR depth does not equal 20 mm!

% preallocation
spctrm_sigma_bdm = zeros(length(c_bdm),length(spctrm));
spctrm_kappa_bdm = zeros(length(c_bdm),length(spctrm));
b634             = zeros(length(c_bdm),1);

for idx = 1:length(c_bdm)
    [~,~,spctrm_sigma_bdm(idx,:),spctrm_kappa_bdm(idx,:),b634(idx)] = calculate_opt_props(m_ccell(idx,:),w_chla(idx),w_chlb(idx),w_car(idx),Ea_chla,Ea_chlb,Ea_car,M_chla,M_chlb);
end

quest_1   = 'Should the light profile be determined for the flat-panel photobioreactor (PBR) or the photosynthesis measurement cell (PMC)?';
p_check_1 = questdlg(quest_1,'System selection','PBR','PMC','PMC');

if strcmp(p_check_1,'PBR')
    LED_spctrm = data.avrg_LED_R_spctrm;

    % preallocation
    PAR_PFD_dzR    = zeros(length(PFD0),length(dzR));
    spctrm_PFD_dzR = zeros(length(PFD0),length(dzR),length(spctrm));

    for idx = 1:length(c_bdm)
        [PAR_PFD_dzR(idx,:),spctrm_PFD_dzR(idx,:,:)] = calculate_light_grad(PFD0(idx),LED_spctrm,c_bdm(idx),spctrm_sigma_bdm(idx,:),spctrm_kappa_bdm(idx,:),b634(idx));
    end

    mean_PAR_PFD = mean(PAR_PFD_dzR,2);
elseif strcmp(p_check_1,'PMC')
    LED_spctrm = data.avrg_LED_PMC_spctrm;

    quest_2   = 'Is each photoacclimated state examined under all PFD0 (-> fast PI-curve)?';
    p_check_2 = questdlg(quest_2,'System selection','Yes','No','Yes');

    if strcmp(p_check_2,'Yes')
    % preallocation
    PAR_PFD_dzR    = zeros(length(c_bdm),length(PFD0),length(dzR));
    spctrm_PFD_dzR = zeros(length(c_bdm),length(PFD0),length(dzR),length(spctrm));

    for idx = 1:length(c_bdm)
        for idx1 = 1:length(PFD0)
            [PAR_PFD_dzR(idx,idx1,:),spctrm_PFD_dzR(idx,idx1,:,:)] = calculate_light_grad(PFD0(idx1),LED_spctrm,c_bdm(idx),spctrm_sigma_bdm(idx,:),spctrm_kappa_bdm(idx,:),b634(idx));
        end
    end

    mean_PAR_PFD = mean(PAR_PFD_dzR,3);
    elseif strcmp(p_check_2,'No')
        % preallocation
        PAR_PFD_dzR    = zeros(length(PFD0),length(dzR));
        spctrm_PFD_dzR = zeros(length(PFD0),length(dzR),length(spctrm));
    
        for idx = 1:length(c_bdm)
            [PAR_PFD_dzR(idx,:),spctrm_PFD_dzR(idx,:,:)] = calculate_light_grad(PFD0(idx),LED_spctrm,c_bdm(idx),spctrm_sigma_bdm(idx,:),spctrm_kappa_bdm(idx,:),b634(idx));
        end
    
        mean_PAR_PFD = mean(PAR_PFD_dzR,2);
    else
        disp('Selection canceled.');
    end
else
    disp('Selection canceled. Please choose a system (PBR or PMC)!');
end