function [p_phi_RCII,stat_tbl] = fit_logfunc_phi_RCII(PFD,phi_RCII)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function fits the logistic function to the phi_RCII (Fv'/Fm') data.
% The results are also plotted for a visual check.
% 
% Inputs:
% PFD: acclimation PFD [µmol/m²/s]
% phi_RCII: maximum RCII-efficiency at a given PPFD [-]
% -> corresponds to Fv'/Fm' in:
%
% Baker, N. R. (2008): Chlorophyll fluorescence: a probe of photosynthesis 
% in vivo. In: Annual review of plant biology 59, S. 89–113. 
% DOI: 10.1146/annurev.arplant.59.032607.092759.
%
% Outputs:
% p_phi_RCII: parameters of the logistic fit function that was fit to the
% phi_RCII (Fv'/Fm') data
% stat_tbl: table with the statistical parameters (R², RMSE, normalized
% RMSE, MBE and normalized MBE)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

logistic_fit_func = @(p,x) p(2)+(p(1)-p(2))./(1+(x./p(3)).^p(4));

p0_phi_RCII  = [min(phi_RCII);mean(phi_RCII);mean(PFD);1];
lb_phi_RCII  = [0.5*max(phi_RCII);0.5*min(phi_RCII);min(PFD);0];
ub_phi_RCII  = [1.5*max(phi_RCII);1.5*min(phi_RCII);max(PFD);10];
p_phi_RCII   = lsqcurvefit(logistic_fit_func,p0_phi_RCII,PFD,phi_RCII,lb_phi_RCII,ub_phi_RCII);

R2    = 1-sum((phi_RCII-logistic_fit_func(p_phi_RCII,PFD)).^2)./sum((phi_RCII-mean(phi_RCII)).^2);

RMSE  = sqrt(sum((phi_RCII-logistic_fit_func(p_phi_RCII,PFD)).^2)./length(phi_RCII));

nRMSE = RMSE./mean(phi_RCII).*100;

MBE   = sum(logistic_fit_func(p_phi_RCII,PFD)-phi_RCII)./length(phi_RCII);

nMBE  = MBE./mean(phi_RCII).*100;

stat_tbl = table({'phi_RCII'},R2',RMSE',nRMSE',MBE',nMBE');
stat_tbl.Properties.VariableNames = {'phi_RCII','R2 [-]','RMSE [-]','nRMSE [%]','MBE [-]','nMBE [%]'};

plot(PFD,phi_RCII,'ko',min(PFD):10:max(PFD),logistic_fit_func(p_phi_RCII,min(PFD):10:max(PFD)),'k-');
xlabel('PFD [µmol/m²/s]');
ylabel('phi_{RCII} [-]');
legend('phi_{RCII}','fitted phi_{RCII}');
grid on;