function [p_w_chla,p_w_chlb,p_w_car,stat_tbl] = fit_logfunc_pigm(PFD,w_chla,w_chlb,w_car)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This function fits the logistic function to the raw pigment data
% (weight-fraction of the corresponding pigment). The results are also
% plotted for visual check.
% 
% Inputs:
% PFD: acclimation PFD [µmol/m²/s]
% w_chla: weight-fraction of Chlorophyll a [g/g]
% w_chlb: weight-fraction of Chlorophyll b [g/g]
% w_car: weight-fraction of the Carotenoids [g/g]
%
% Outputs:
% p_w_chla: parameters of the logistic fit function that was fit to the
% Chlorophyll a data
% p_w_chlb: parameters of the logistic fit function that was fit to the
% Chlorophyll b data
% p_w_car: parameters of the logistic fit function that was fit to the
% Carotenoids data
% stat_tbl: table with the statistical parameters (R², RMSE, normalized
% RMSE, MBE and normalized MBE)
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

logistic_fit_func = @(p,x) p(2)+(p(1)-p(2))./(1+(x./p(3)).^p(4));

p0_chla  = [min(w_chla);mean(w_chla);mean(PFD);1];
lb_chla  = [0.5*max(w_chla);0.5*min(w_chla);min(PFD);0];
ub_chla  = [1.5*max(w_chla);1.5*min(w_chla);max(PFD);10];
p_w_chla = lsqcurvefit(logistic_fit_func,p0_chla,PFD,w_chla,lb_chla,ub_chla);

p0_chlb  = [min(w_chlb);mean(w_chlb);mean(PFD);1];
lb_chlb  = [0.5*max(w_chlb);0.5*min(w_chlb);min(PFD);0];
ub_chlb  = [1.5*max(w_chlb);1.5*min(w_chlb);max(PFD);10];
p_w_chlb = lsqcurvefit(logistic_fit_func,p0_chlb,PFD,w_chlb,lb_chlb,ub_chlb);

p0_car  = [min(w_car);mean(w_car);mean(PFD);1];
lb_car  = [0.5*max(w_car);0.5*min(w_car);min(PFD);0];
ub_car  = [1.5*max(w_car);1.5*min(w_car);max(PFD);10];
p_w_car = lsqcurvefit(logistic_fit_func,p0_car,PFD,w_car,lb_car,ub_car);

R2(1)    = 1-sum((w_chla-logistic_fit_func(p_w_chla,PFD)).^2)./sum((w_chla-mean(w_chla)).^2);
R2(2)    = 1-sum((w_chlb-logistic_fit_func(p_w_chlb,PFD)).^2)./sum((w_chlb-mean(w_chlb)).^2);
R2(3)    = 1-sum((w_car-logistic_fit_func(p_w_car,PFD)).^2)./sum((w_car-mean(w_car)).^2);

RMSE(1)  = sqrt(sum((w_chla-logistic_fit_func(p_w_chla,PFD)).^2)./length(w_chla));
RMSE(2)  = sqrt(sum((w_chlb-logistic_fit_func(p_w_chlb,PFD)).^2)./length(w_chlb));
RMSE(3)  = sqrt(sum((w_car-logistic_fit_func(p_w_car,PFD)).^2)./length(w_car));

nRMSE(1) = RMSE(1)./mean(w_chla).*100;
nRMSE(2) = RMSE(2)./mean(w_chlb).*100;
nRMSE(3) = RMSE(3)./mean(w_car).*100;

MBE(1)   = sum(logistic_fit_func(p_w_chla,PFD)-w_chla)./length(w_chla);
MBE(2)   = sum(logistic_fit_func(p_w_chlb,PFD)-w_chlb)./length(w_chlb);
MBE(3)   = sum(logistic_fit_func(p_w_car,PFD)-w_car)./length(w_car);

nMBE(1)  = MBE(1)./mean(w_chla).*100;
nMBE(2)  = MBE(2)./mean(w_chlb).*100;
nMBE(3)  = MBE(3)./mean(w_car).*100;

stat_tbl = table({'Chlorophyll a';'Chlorophyll b';'Carotenoids'},...
    R2',RMSE',nRMSE',MBE',nMBE');
stat_tbl.Properties.VariableNames = {'Pigment','R2 [-]','RMSE [g/g]','nRMSE [%]','MBE [g/g]','nMBE [%]'};

plot(PFD,w_chla,'go',min(PFD):10:max(PFD),logistic_fit_func(p_w_chla,min(PFD):10:max(PFD)),'g-',...
    PFD,w_chlb,'bo',min(PFD):10:max(PFD),logistic_fit_func(p_w_chlb,min(PFD):10:max(PFD)),'b-',...
    PFD,w_car,'ro',min(PFD):10:max(PFD),logistic_fit_func(p_w_car,min(PFD):10:max(PFD)),'r-');
xlabel('PFD [µmol/m²/s]');
ylabel('pigment weight-fraction [g/g]');
legend('Chla','fitted Chla','Chlb','fitted Chlb','Car','fitted Car');
grid on;