function [apprx_n_RCII_chl,apprx_n_RCI_chl] = calculate_LHCRC_size(chlab_ratio,RCI_RCII_ratio,phi_RCII,M_chla,M_chlb)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This script derives the approximated size of the LHCII-RCII and LHCI-RCI
% complexes from the macroscopic chla/chlb ratios.
%
% Inputs:
% chlab_ratio: macroscopic chla/chlb ratio (w_chla/w_chlb) [-]
% RCI_RCII_ratio: RCI/RCII ratio [-]
% phi_RCII: maximum quantum yield of RCII (corresponds to Fv'/Fm') [-]
% M_chla, M_chlb: molecular weight of chla & chlb [g/mol]
%
% Outputs:
% apprx_n_RCII_chl: number of chl (chla+chlb) per LHCII-RCII [-]
% apprx_n_RCI_chl: number of chl (chla+chlb) per LHCI-RCI [-]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% shown values & assumptions are based on the data from:
% 
% Albanese, P.; Manfredi, M.; Meneghesso, A.; Marengo, E.; Saracco, G.; 
% Barber, J. et al. (2016): Dynamic reorganization of photosystem II 
% supercomplexes in response to variations in light intensities. 
% In: Biochimica et biophysica acta 1857 (10), 
% S. 1651–1660. DOI: 10.1016/j.bbabio.2016.06.011.
%
% and
%
% Shen, L.; Huang, Z.; Chang, S.; Wang, W.; Wang, J.; Kuang, T.;
% et al. (2019): Structure of a C2S2M2N2-type PSII-LHCII supercomplex 
% from the green alga Chlamydomonas reinhardtii. 
% In: Proceedings of the National Academy of Sciences of 
% the United States of America 116 (42), 
% S. 21246–21255. DOI: 10.1073/pnas.1912462116.

n_RCII_chl = [126,78; % upper/lower bound of the chla-number per LHCII-RCII
             61,25];  % upper/lower bound of the chlb-number per LHCII-RCII
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% shown values & assumptions are based on the data from:
% 
% Haniewicz, P.; Abram, M.; Nosek, L.; Kirkpatrick, J.; El-Mohsnawy, E.; 
% Olmos, J. D. J. et al. (2018): Molecular Mechanisms of Photoadaptation of
% Photosystem I Supercomplex from an Evolutionary 
% Cyanobacterial/Algal Intermediate. In: Plant physiology 176 (2), 
% S. 1433–1451. DOI: 10.1104/pp.17.01022.
% 
% Le Quiniou, C.; Tian, L.; Drop, B.; Wientjes, E.; van Stokkum, I. H. M.; 
% van Oort, B.; Croce, R. (2015): PSI-LHCI of Chlamydomonas reinhardtii: 
% Increasing the absorption cross section without losing efficiency. 
% In: Biochimica et biophysica acta 1847 (4-5), 
% S. 458–467. DOI: 10.1016/j.bbabio.2015.02.001.
%
% and
%
% Stauber, E. J.; Busch, A.; Naumann, B.; Svatos, A.; Hippler, M. (2009): 
% Proteotypic profiling of LHCI from Chlamydomonas reinhardtii provides 
% new insights into structure and function of the complex. 
% In: Proteomics 9 (2), S. 398–408. DOI: 10.1002/pmic.200700620.

n_RCI_chl  = [186,138; % upper/lower bound of the chla-number per LHCI-RCI
             40,18];   % upper/lower bound of the chlb-number per LHCI-RCI
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

n_RCII_chl_max = n_RCII_chl(1,1)+n_RCII_chl(2,1);
n_RCII_chl_min = n_RCII_chl(1,2)+n_RCII_chl(2,2);
n_RCI_chl_max  = n_RCI_chl(1,1)+n_RCI_chl(2,1);
n_RCI_chl_min  = n_RCI_chl(1,2)+n_RCI_chl(2,2);

x = zeros(length(chlab_ratio),2);

for idx = 1:length(chlab_ratio)
    sim_chl_ratio = @(x) (x(:,1)*n_RCII_chl(1,1)+(1-x(:,1))...
        *n_RCII_chl(1,2)+RCI_RCII_ratio*(x(:,2)*n_RCI_chl(1,1)...
        +(1-x(:,2))*n_RCI_chl(1,2)))./(x(:,1)*n_RCII_chl(2,1)...
        +(1-x(:,1))*n_RCII_chl(2,2)+RCI_RCII_ratio*(x(:,2)...
        *n_RCI_chl(2,1)+(1-x(:,2))*n_RCI_chl(2,2)));

    obj_func = @(x) (chlab_ratio(idx)-(M_chla/M_chlb)*sim_chl_ratio(x))^2;

    x0   = [0.8,0.2];

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% condition that the effective size of an LHCI-RCI complex must always be 
% at least 25% larger than the size of the LHCII-RCII complex
%
% for reference see:
%
% Allen, J. F. (2003): Cyclic, pseudocyclic and noncyclic 
% photophosphorylation: new links in the chain. 
% In: Trends in Plant Science 8 (1), 
% S. 15–19. DOI: 10.1016/S1360-1385(02)00006-7.

    A_x  = [5*phi_RCII(idx)*(n_RCII_chl_max-n_RCII_chl_min)...
        /(4*RCI_RCII_ratio*0.98*(n_RCI_chl_max-n_RCI_chl_min)),-1];

    b_x  = n_RCI_chl_min/(n_RCI_chl_max-n_RCI_chl_min)-5*phi_RCII(idx)...
        *n_RCII_chl_min/(4*RCI_RCII_ratio*0.98...
        *(n_RCI_chl_max-n_RCI_chl_min));
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

    lb_x = zeros(1,length(x0));
    ub_x = ones(1,length(x0));

    x(idx,:) = fmincon(obj_func,x0,A_x,b_x,[],[],lb_x,ub_x);
end

apprx_n_RCII_chla = x(:,1).*n_RCII_chl(1,1)+(1-x(:,1)).*n_RCII_chl(1,2);
apprx_n_RCII_chlb = x(:,1).*n_RCII_chl(2,1)+(1-x(:,1)).*n_RCII_chl(2,2);
apprx_n_RCII_chl  = apprx_n_RCII_chla+apprx_n_RCII_chlb;

apprx_n_RCI_chla = x(:,2).*n_RCI_chl(1,1)+(1-x(:,2)).*n_RCI_chl(1,2);
apprx_n_RCI_chlb = x(:,2).*n_RCI_chl(2,1)+(1-x(:,2)).*n_RCI_chl(2,2);
apprx_n_RCI_chl  = apprx_n_RCI_chla+apprx_n_RCI_chlb;
