function obj_func_val = call_obj_func(k_PSU_model)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% This script calculates the value of the objective function based on the 
% parameter values of k (k_RCII,lim & k_PSU,lim).
% Note that this parameter estimation routine is not optimized for
% computational efficiency.
%
% Inputs:
% k_PSU_model: values of k_RCII,lim (1) & k_PSU,lim (2) as a column vector
% [1/s]
%
% Outputs:
% obj_func_val: value of the objective function (subject to minimization)
% [-]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% load data necessary for parameter estimation 
% (own experimental data and literature values)
% All data is stored in column vectors (if possible) or scalars.

data = load('accl_fast_data.mat');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% own experimental and calculated/estimated data

ss_PFD              = data.ss_fast_PFD;

% dim. of P_Netto_LLMLHL: [accl. states X set PFD0s] -> in this case: [3x7]
P_Netto_LLMLHL      = data.LLMLHL_fast_P_Netto;

% dim. of PMC_PFD_dzR & PMC_PFD_quanta_dzR:
% [accl. states X set PFD0s X num. of steps along the PBR depth]
% -> in this case: [3x7x20]
PMC_PFD_dzR         = data.LLMLHL_fast_PMC_PFD_dzR;
PMC_PFD_quanta_dzR  = PMC_PFD_dzR.*6.02214076e23./1e6;

p_car               = data.ss_accl_p_w_car;
p_chla              = data.ss_accl_p_w_chla;
p_chlb              = data.ss_accl_p_w_chlb;
p_phi_RCII          = data.ss_accl_p_phi_RCII;

n_Rubisco_max_bdm   = data.ss_accl_n_Rubisco_max_bdm;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% m_ccel was calculated as described in:
%
% Kandilian, R.; Pruvost, J.; Artu, A.; Lemasson, C.; Legrand, J.; 
% Pilon, L. (2016): Comparison of experimentally and theoretically 
% determined radiation characteristics of photosynthetic microorganisms. 
% In: Journal of Quantitative Spectroscopy and Radiative Transfer 175, 
% S. 30–45. DOI: 10.1016/j.jqsrt.2016.01.031.
%
% The imaginary part of the RI of the cell core (k_ccell) was determined
% according to Kandilian et al. (2016). k_ccell was then used to calculate
% the corresponding real part of the RI (n_ccell) using the 
% singly-substractive Kronig-Kramers (ssKK) relation.
% The ssKK script utilized can be found in:
%
% Lucarini, V.; Peiponen, K.-E.; Saarinen, J. J.; Vartiainen, E. M. (2005):
% Kramers-Kronig relations in optical materials research. Berlin, 
% Heidelberg: Springer-Verlag Berlin Heidelberg 
% (Springer Series in Optical Sciences, 110).
%
% with: m_ccell = n_ccell + i*k_ccell

m_ccell             = data.ss_fast_fit_m_ccell;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% y_P_Brutto value of 0.32 is taken from:
%
% Geider, R. J.; Osborne, B. A. (1989): Respiration and microalgal growth: 
% a review of the quantitative relationship between dark respiration 
% and growth. In: New Phytol 112 (3), 
% S. 327–341. DOI: 10.1111/j.1469-8137.1989.tb00321.x.
%
% r_mnt_bdm in mol/g/s was converted from the r_mnt_bdm value of 
% 0.53 mmol/g/h from:
%
% Kliphuis, A. M. J.; Klok, A. J.; Martens, D. E.; Lamers, P. P.; Janssen, 
% M.; Wijffels, R. H. (2012): Metabolic modeling of Chlamydomonas 
% reinhardtii: energy requirements for photoautotrophic growth and 
% maintenance. In: J Appl Phycol 24 (2), 
% S. 253–266. DOI: 10.1007/s10811-011-9674-3.

y_P_Brutto          = data.ss_accl_y_resp_P_Brutto;
r_mnt_bdm           = data.ss_accl_r_mnt_bdm;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Ea_i data is available here (requires interpolation between 400-700 nm
% with 1 nm steps):
%
% Bidigare, R. R.; Ondrusek, M. E.; Morrow, J. H.; Kiefer, D. A. (1990): 
% In-vivo absorption properties of algal pigments. 
% In: Richard W. Spinrad (Hg.): Ocean Optics X. Orlando '90, 16-20 April. 
% Orlando, FL, United States: SPIE (SPIE Proceedings), S. 290.
%
% or in (only 400-700 nm range is required):
%
% Dauchet, J.; Blanco, S.; Cornet, J.-F.; Fournier, R. (2015): 
% Calculation of the radiative properties of photosynthetic microorganisms. 
% In: Journal of Quantitative Spectroscopy and Radiative Transfer 161, 
% S. 60–84. DOI: 10.1016/j.jqsrt.2015.03.025.
% -> http://edstar.lmd.jussieu.fr/databases

Ea_chla     = data.Ea_chla;
Ea_chlb     = data.Ea_chlb;
Ea_car      = data.Ea_car; % only photoprotective carotenoids are considered
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

M_chla = data.M_chla; % molecular weight of chla [g/mol]
M_chlb = data.M_chlb; % molecular weight of chlb [g/mol]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% fits are used to reduce the noise of the experimental data

logistic_fit_func   = @(p,x) p(2)+(p(1)-p(2))./(1+(x./p(3)).^p(4));

fit_w_chla       = logistic_fit_func(p_chla,ss_PFD);
fit_w_chlb       = logistic_fit_func(p_chlb,ss_PFD);
fit_w_car        = logistic_fit_func(p_car,ss_PFD);

fit_chlab_ratio  = fit_w_chla./fit_w_chlb;

fit_phi_RCII     = logistic_fit_func(p_phi_RCII,ss_PFD);

% conversion of r_mnt unit from mol O2/g bdm/s to mol O2/mol chl/s
fit_r_mnt        = r_mnt_bdm./(fit_w_chla./M_chla+fit_w_chlb./M_chlb);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% assumed to be constant, value based on data from:
%
% Greenbaum, N. L.; Mauzerall, D. (1991): Effect of irradiance level on 
% distribution of chlorophylls between PS II and PS I as determined from 
% optical cross-sections. 
% In: Biochimica et Biophysica Acta (BBA) - Bioenergetics 1057 (2), 
% S. 195–207. DOI: 10.1016/S0005-2728(05)80102-1.

RCI_RCII_ratio  = 1.1;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

n_PQ = 8; % assumed to be constant (based on own experimental data)

[apprx_n_RCII_chl,apprx_n_RCI_chl] = calculate_LHCRC_size(fit_chlab_ratio,RCI_RCII_ratio,fit_phi_RCII,M_chla,M_chlb);

% approx. number of chl per photosynthetic unit (PSU)
apprx_n_PSU_chl = apprx_n_RCII_chl+RCI_RCII_ratio.*apprx_n_RCI_chl;

n_Rubisco = calculate_n_Rubisco_per_RCII(fit_w_chla,fit_w_chlb,M_chla,M_chlb,apprx_n_PSU_chl,n_Rubisco_max_bdm);

% preallocation
fit_avrg_sigma_chl = zeros(size(PMC_PFD_dzR,1),1);

parfor idx = 1:size(PMC_PFD_dzR,1)
    fit_avrg_sigma_chl(idx) = calculate_opt_props(m_ccell(idx,:),fit_w_chla(idx),fit_w_chlb(idx),fit_w_car(idx),Ea_chla,Ea_chlb,Ea_car,M_chla,M_chlb);
end

fit_avrg_sigma_RCII = fit_avrg_sigma_chl.*apprx_n_RCII_chl;

% preallocation
x = zeros(size(PMC_PFD_dzR,1),size(PMC_PFD_dzR,2),size(PMC_PFD_dzR,3),4);

parfor idx = 1:size(PMC_PFD_dzR,1)
    x(idx,:,:,:) = solve_model_eqsys(k_PSU_model,PMC_PFD_quanta_dzR(idx,:,:),fit_avrg_sigma_RCII(idx),fit_phi_RCII(idx),n_PQ,n_Rubisco(idx));
end

% preallocation
sim_P_Netto_LLMLHL_dzR  = zeros(size(PMC_PFD_dzR,1),size(PMC_PFD_dzR,2),size(PMC_PFD_dzR,3));
sim_P_Netto_LLMLHL      = zeros(size(PMC_PFD_dzR,1),size(PMC_PFD_dzR,2));

for idx1 = 1:size(PMC_PFD_dzR,1)
    for idx2 = 1:size(PMC_PFD_dzR,2)
        for idx3 = 1:size(PMC_PFD_dzR,3)
            sim_P_Netto_LLMLHL_dzR(idx1,idx2,idx3) = 0.25...
                .*(k_PSU_model(2).*n_Rubisco(idx1).*x(idx1,idx2,idx3,end))...
                ./apprx_n_PSU_chl(idx1).*(1-y_P_Brutto)-fit_r_mnt(idx1);
        end
    end

    sim_P_Netto_LLMLHL(idx1,idx2) = mean(sim_P_Netto_LLMLHL_dzR(idx1,idx2,:),3);
end

g = ones(size(P_Netto_LLMLHL)); % weighting matrix

obj_func_val = sum(g.*(P_Netto_LLMLHL-sim_P_Netto_LLMLHL).^2,'all');