function [sim_PMC_PFD_dzR,sim_x_dzR,sim_P_Netto_dzR,sim_r_diss_dzR,stat_tbl] = plot_results(k_PSU_model,varargin)

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Use this script to plot the results after the parameter estimation.
% Please adjust the plotting part of this script to your needs and the 
% properties of your data (number of different acclimation states, etc.).
% In addition to the plotting routines, this script provides several
% outsputs (simulated data) for further processing as well as statistical
% parameters to evaluate the fit of the PSU-model.  
% 
% Inputs:
% k_PSU_model: values of k_RCII,lim (1) & k_PSU,lim (2) as a column vector
% [1/s]
% varargin: optional input, only required if a line plot is desired
% -> sim_PMC_PFD_dzR [µmol/(m²*s)], 1. and 3. dimensions must be the same 
% as for LLMLHL_fast_PMC_PFD_dzR; only 1 input is allowed, several inputs
% will lead to an error!
%
% Outputs:
% sim_PMC_PFD_dzR: simulated light profiles along the PMC depth for each 
% state [µmol/(m²*s)]; corresponds to LLMLHL_fast_PMC_PFD_dzR if no
% optional input is provided
% sim_x_dzR: fractions of the modelled PSU-components (x_RCII_open,
% x_RCII_closed, x_PQ_open & x_PQ_closed) [-]
% sim_P_Netto_dzR: simulated local Chlorophyll-specific oxygenic
% photosynthetic rates for each state [mol/(mol*s)]
% sim_r_diss_dzR: simulated local PSU-specific energy dissipation rate for
% each state [1/s]
% stat_tbl: table with the statistical parameters (R², RMSE, normalized
% RMSE, MBE, normalized MBE and adjusted Akaike information criterion
% (AICc))
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% load data

data = load('accl_fast_data.mat');
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

ss_PFD      = data.ss_fast_PFD;
PMC_PFD_dzR = data.LLMLHL_fast_PMC_PFD_dzR;
P_Netto     = data.LLMLHL_fast_P_Netto;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Ea_i data is available here (requires interpolation between 400-700 nm
% with 1 nm steps):
%
% Bidigare, R. R.; Ondrusek, M. E.; Morrow, J. H.; Kiefer, D. A. (1990): 
% In-vivo absorption properties of algal pigments. 
% In: Richard W. Spinrad (Hg.): Ocean Optics X. Orlando '90, 16-20 April. 
% Orlando, FL, United States: SPIE (SPIE Proceedings), S. 290.
%
% or in (only 400-700 nm range is required):
%
% Dauchet, J.; Blanco, S.; Cornet, J.-F.; Fournier, R. (2015): 
% Calculation of the radiative properties of photosynthetic microorganisms. 
% In: Journal of Quantitative Spectroscopy and Radiative Transfer 161, 
% S. 60–84. DOI: 10.1016/j.jqsrt.2015.03.025.
% -> http://edstar.lmd.jussieu.fr/databases

Ea_chla = data.Ea_chla;
Ea_chlb = data.Ea_chlb;
Ea_car  = data.Ea_car; % only photoprotective carotenoids are considered
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

M_chla = data.M_chla; % molecular weight of chla [g/mol]
M_chlb = data.M_chlb; % molecular weight of chlb [g/mol]
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% m_ccel was calculated as described in:
%
% Kandilian, R.; Pruvost, J.; Artu, A.; Lemasson, C.; Legrand, J.; 
% Pilon, L. (2016): Comparison of experimentally and theoretically 
% determined radiation characteristics of photosynthetic microorganisms. 
% In: Journal of Quantitative Spectroscopy and Radiative Transfer 175, 
% S. 30–45. DOI: 10.1016/j.jqsrt.2016.01.031.
%
% The imaginary part of the RI of the cell core (k_ccell) was determined
% according to Kandilian et al. (2016). k_ccell was then used to calculate
% the corresponding real part of the RI (n_ccell) using the 
% singly-substractive Kronig-Kramers (ssKK) relation.
% The ssKK script utilized can be found in:
%
% Lucarini, V.; Peiponen, K.-E.; Saarinen, J. J.; Vartiainen, E. M. (2005):
% Kramers-Kronig relations in optical materials research. Berlin, 
% Heidelberg: Springer-Verlag Berlin Heidelberg 
% (Springer Series in Optical Sciences, 110).
%
% with: m_ccell = n_ccell + i*k_ccell

fit_m_ccell = data.ss_fast_fit_m_ccell;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

p_car               = data.ss_accl_p_w_car;
p_chla              = data.ss_accl_p_w_chla;
p_chlb              = data.ss_accl_p_w_chlb;
p_phi_RCII          = data.ss_accl_p_phi_RCII;

n_Rubisco_max_bdm   = data.ss_accl_n_Rubisco_max_bdm;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% y_P_Brutto value of 0.32 is taken from:
%
% Geider, R. J.; Osborne, B. A. (1989): Respiration and microalgal growth: 
% a review of the quantitative relationship between dark respiration 
% and growth. In: New Phytol 112 (3), 
% S. 327–341. DOI: 10.1111/j.1469-8137.1989.tb00321.x.
%
% r_mnt_bdm in mol/g/s was converted from the r_mnt_bdm value of 
% 0.53 mmol/g/h from:
%
% Kliphuis, A. M. J.; Klok, A. J.; Martens, D. E.; Lamers, P. P.; Janssen, 
% M.; Wijffels, R. H. (2012): Metabolic modeling of Chlamydomonas 
% reinhardtii: energy requirements for photoautotrophic growth and 
% maintenance. In: J Appl Phycol 24 (2), 
% S. 253–266. DOI: 10.1007/s10811-011-9674-3.

y_P_Brutto          = data.ss_accl_y_resp_P_Brutto;
r_mnt_bdm           = data.ss_accl_r_mnt_bdm;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% fits are used to reduce the noise of the experimental data

logistic_fit_func   = @(p,x) p(2)+(p(1)-p(2))./(1+(x./p(3)).^p(4));

fit_w_chla       = logistic_fit_func(p_chla,ss_PFD);
fit_w_chlb       = logistic_fit_func(p_chlb,ss_PFD);
fit_w_car        = logistic_fit_func(p_car,ss_PFD);

fit_chlab_ratio  = fit_w_chla./fit_w_chlb;

fit_phi_RCII     = logistic_fit_func(p_phi_RCII,ss_PFD);

% conversion of r_mnt unit from mol O2/g bdm/s to mol O2/mol chl/s
fit_r_mnt        = r_mnt_bdm./(fit_w_chla./M_chla+fit_w_chlb./M_chlb);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% assumed to be constant, value based on data from:
%
% Greenbaum, N. L.; Mauzerall, D. (1991): Effect of irradiance level on 
% distribution of chlorophylls between PS II and PS I as determined from 
% optical cross-sections. 
% In: Biochimica et Biophysica Acta (BBA) - Bioenergetics 1057 (2), 
% S. 195–207. DOI: 10.1016/S0005-2728(05)80102-1.

RCI_RCII_ratio  = 1.1;
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

n_PQ = 8; % assumed to be constant (based on own experimental data)

[apprx_n_RCII_chl,apprx_n_RCI_chl] = calculate_LHCRC_size(fit_chlab_ratio,RCI_RCII_ratio,fit_phi_RCII,M_chla,M_chlb);

% approx. number of chl per photosynthetic unit (PSU)
apprx_n_PSU_chl = apprx_n_RCII_chl+RCI_RCII_ratio.*apprx_n_RCI_chl;

n_Rubisco = calculate_n_Rubisco_per_RCII(fit_w_chla,fit_w_chlb,M_chla,M_chlb,apprx_n_PSU_chl,n_Rubisco_max_bdm);

if isempty(varargin)
    PMC_PFD_quanta_dzR = PMC_PFD_dzR.*6.02214076e23./1e6;
elseif length(varargin) == 1
    PMC_PFD_quanta_dzR = cat(2,PMC_PFD_dzR,varargin{1}).*6.02214076e23./1e6;
    PMC_PFD_quanta_dzR = sort(PMC_PFD_quanta_dzR,2);
elseif length(varargin) ~= 1
    error('Only sim_PMC_PFD_dzR is allowed as variable input!');
end

% preallocation
fit_avrg_sigma_chl = zeros(size(PMC_PFD_quanta_dzR,1),1);

parfor idx = 1:size(PMC_PFD_quanta_dzR,1)
    fit_avrg_sigma_chl(idx) = calculate_opt_props(fit_m_ccell(idx,:),fit_w_chla(idx),fit_w_chlb(idx),fit_w_car(idx),Ea_chla,Ea_chlb,Ea_car,M_chla,M_chlb);
end

fit_avrg_sigma_RCII = fit_avrg_sigma_chl.*apprx_n_RCII_chl;

% preallocation
sim_x_dzR = zeros(size(PMC_PFD_quanta_dzR,1),size(PMC_PFD_quanta_dzR,2),size(PMC_PFD_quanta_dzR,3),4);

parfor idx = 1:size(PMC_PFD_quanta_dzR,1)
    sim_x_dzR(idx,:,:,:) = solve_model_eqsys(k_PSU_model,PMC_PFD_quanta_dzR(idx,:,:),fit_avrg_sigma_RCII(idx),fit_phi_RCII(idx),n_PQ,n_Rubisco(idx));
end

% preallocation
sim_P_Netto_dzR  = zeros(size(PMC_PFD_quanta_dzR,1),size(PMC_PFD_quanta_dzR,2),size(PMC_PFD_quanta_dzR,3));
sim_P_Netto      = zeros(size(PMC_PFD_quanta_dzR,1),size(PMC_PFD_quanta_dzR,2));
sim_r_diss_dzR   = zeros(size(PMC_PFD_quanta_dzR,1),size(PMC_PFD_quanta_dzR,2),size(PMC_PFD_quanta_dzR,3));
R2               = zeros(size(PMC_PFD_quanta_dzR,1),1);
RMSE             = zeros(size(PMC_PFD_quanta_dzR,1),1);
nRMSE            = zeros(size(PMC_PFD_quanta_dzR,1),1);
MBE              = zeros(size(PMC_PFD_quanta_dzR,1),1);
nMBE             = zeros(size(PMC_PFD_quanta_dzR,1),1);
AICc             = zeros(size(PMC_PFD_quanta_dzR,1),1);

for idx1 = 1:size(PMC_PFD_quanta_dzR,1)
    for idx2 = 1:size(PMC_PFD_quanta_dzR,2)
        for idx3 = 1:size(PMC_PFD_quanta_dzR,3)
            sim_P_Netto_dzR(idx1,idx2,idx3) = 0.25...
                .*(k_PSU_model(2).*n_Rubisco(idx1).*sim_x_dzR(idx1,idx2,idx3,end))...
                ./apprx_n_PSU_chl(idx1).*(1-y_P_Brutto)-fit_r_mnt(idx1);
            
            sim_r_diss_dzR(idx1,idx2,idx3) = fit_avrg_sigma_RCII(idx1)*PMC_PFD_quanta_dzR(idx1,idx2,idx3)*(1-fit_phi_RCII(idx1)*sim_x_dzR(idx1,idx2,idx3,1)); 
        end

        sim_P_Netto(idx1,idx2) = mean(sim_P_Netto_dzR(idx1,idx2,:),3);
    end

    logic_idx   = ismember(PMC_PFD_quanta_dzR(idx1,:,1),PMC_PFD_dzR(idx1,:,1).*6.02214076e23./1e6);
    n           = size(PMC_PFD_quanta_dzR(:,1:size(PMC_PFD_dzR,2),:),2);
    K           = length(k_PSU_model);
    R2(idx1)    = 1-sum((P_Netto(idx1,:)-sim_P_Netto(idx1,logic_idx)).^2)./sum((P_Netto(idx1,:)-mean(P_Netto(idx1,:))).^2);
    RMSE(idx1)  = sqrt(sum((P_Netto(idx1,:)-sim_P_Netto(idx1,logic_idx)).^2)./n);
    nRMSE(idx1) = RMSE(idx1)./mean(P_Netto(idx1,:)).*100;
    MBE(idx1)   = sum((sim_P_Netto(idx1,logic_idx)-P_Netto(idx1,:)))./n;
    nMBE(idx1)  = MBE(idx1)./mean(P_Netto(idx1,:)).*100;
    AICc(idx1)  = n.*log(sum((P_Netto(idx1,:)-sim_P_Netto(idx1,logic_idx)).^2)./n)+2.*(K+1)+2.*(K+1).*(K+2)./(n-K-2);
end

stat_tbl = table(ss_PFD,R2,RMSE,nRMSE,MBE,nMBE,AICc);
stat_tbl.Properties.VariableNames = {'acclimation PFD [µmol/(m²*s)]',...
    'R2 [-]','RMSE [mol/(mol*s)]','nRMSE [%]','MBE [mol/(mol*s)]','nMBE [%]','AICc [-]'};

sim_PMC_PFD_dzR = PMC_PFD_quanta_dzR./6.02214076e23.*1e6;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% plotting the results
% This part of the script should be adjusted to the specific needs and the
% size of the available data set.

if isempty(varargin)
    smbl = 'o';
else
    smbl = '-';
end

figure('WindowState','maximized');

for pidx = 1:size(PMC_PFD_dzR,1)
    subplot(3,3,pidx);
    plot(mean(PMC_PFD_dzR(pidx,:,:),3),P_Netto(pidx,:),'k*',mean(sim_PMC_PFD_dzR(pidx,:,:),3),sim_P_Netto(pidx,:),['r',smbl]);
    grid on;
    xlabel('photon flux density [µmol/(m²*s)]');
    ylabel('Chl-specific photosynthetic rate [mol/(mol*s)]');
    legend({'experimental data','simulated data'},'Location','eastoutside');
    subtitle(['acclimation PFD: ',num2str(ss_PFD(pidx)),' µmol/(m²*s)']);

    subplot(3,3,size(PMC_PFD_dzR,1)+pidx);
    plot(mean(sim_PMC_PFD_dzR(pidx,:,:),3),mean(sim_x_dzR(pidx,:,:,1),3),['k',smbl],...
        mean(sim_PMC_PFD_dzR(pidx,:,:),3),mean(sim_x_dzR(pidx,:,:,2),3),['r',smbl],...
        mean(sim_PMC_PFD_dzR(pidx,:,:),3),mean(sim_x_dzR(pidx,:,:,3),3),['b',smbl],...
        mean(sim_PMC_PFD_dzR(pidx,:,:),3),mean(sim_x_dzR(pidx,:,:,end),3),['g',smbl]);
    grid on;
    xlabel('photon flux density [µmol/(m²*s)]');
    ylabel('fraction of each PSU-component [-]');
    legend({'x_{RCII,open}','x_{RCII,closed}','x_{PQ,open}','x_{PQ,closed}'},'Location','eastoutside');

    subplot(3,3,2*size(PMC_PFD_dzR,1)+pidx);
    plot(mean(sim_PMC_PFD_dzR(pidx,:,:),3),mean(sim_r_diss_dzR(pidx,:,:),3),['k',smbl]);
    grid on;
    xlabel('photon flux density [µmol/(m²*s)]');
    ylabel('PSU-specific energy dissipation rate [1/s]');
    legend({'PSU: photosynthetic unit'},'Location','eastoutside');
end
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%